@@ -10,8 +10,8 @@ def define_feature_group(
     record_identifier_feature,
     event_time_feature,
     feature_definitions,
-    online_store_config,
-    offline_store_config,
+    online_store_config={},
+    offline_store_config={},
     s3_key=None,
     aws_access_key=None,
     aws_secret_key=None,
@@ -32,8 +32,6 @@ def define_feature_group(
     aws_secret_key_id = (
         os.environ["AWS_SECRET_KEY"] if aws_secret_key is None else aws_secret_key
     )
-    region_name = os.environ["AWS_REGION"] if region is None else region
-    role_arn = os.environ["SAGEMAKER_ROLE"] if role is None else role
 
     environment_prefix_name = (
         os.environ["ENVIRONMENT_PREFIX"]
@@ -41,6 +39,23 @@ def define_feature_group(
         else environment_prefix
     )
 
+    data_lake_bucket_name = (
+        os.environ["DATA_LAKE_BUCKET"] if data_lake_bucket is None else data_lake_bucket
+    )
+    data_lake_bucket_name = f"{environment_prefix}{data_lake_bucket_name}"
+    data_lake_bucket_name = data_lake_bucket_name.replace("_", "-")
+
+    region_name = os.environ["AWS_REGION"] if region is None else region
+    role_arn = os.environ["SAGEMAKER_ROLE"] if role is None else role
+
+    offline_store_config_object = (
+        {} if offline_store_config is None else offline_store_config
+    )
+    if s3_key is not None:
+        offline_store_config_object["OfflineStoreConfig"] = {
+            "S3StorageConfig": {"S3Uri": f"s3://{data_lake_bucket_name}/{s3_key}"}
+        }
+
     sagemakerclient = boto3.client(
         "sagemaker",
         aws_access_key_id=aws_access_key_id,
@@ -69,9 +84,7 @@ def define_feature_group(
     if is_different:
         sagemakerclient.delete_feature_group(FeatureGroupName=feature_group_name)
 
-    response = { 
-        "Message": "Feature group already exists with the provided definition."
-    }
+    response = {"Message": "Feature group already exists with the provided definition."}
 
     if is_different or is_new:
         response = sagemakerclient.create_feature_group(
